==> arrow-docs-0.7.3-sources.jar: arrow/optics/Company$$optics.kt <==
package `arrow`.`optics`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `arrow`.`optics`.`Company`.Companion.iso: arrow.optics.Iso<`arrow`.`optics`.`Company`, arrow.core.Tuple2<`kotlin`.`String`, `arrow`.`optics`.`Address`>> inline get()= arrow.optics.Iso(
  get = { company: `arrow`.`optics`.`Company` -> arrow.core.Tuple2(company.`name`, company.`address`) },
  reverseGet = { tuple: arrow.core.Tuple2<`kotlin`.`String`, `arrow`.`optics`.`Address`> -> `arrow`.`optics`.`Company`(tuple.a, tuple.b) }
)

inline val `arrow`.`optics`.`Company`.Companion.name: arrow.optics.Lens<`arrow`.`optics`.`Company`, `kotlin`.`String`> inline get()= arrow.optics.Lens(
  get = { company: `arrow`.`optics`.`Company` -> company.`name` },
  set = { value: `kotlin`.`String` ->
    { company: `arrow`.`optics`.`Company` ->
      company.copy(`name` = value)
    }
  }
)

inline val `arrow`.`optics`.`Company`.Companion.address: arrow.optics.Lens<`arrow`.`optics`.`Company`, `arrow`.`optics`.`Address`> inline get()= arrow.optics.Lens(
  get = { company: `arrow`.`optics`.`Company` -> company.`address` },
  set = { value: `arrow`.`optics`.`Address` ->
    { company: `arrow`.`optics`.`Company` ->
      company.copy(`address` = value)
    }
  }
)




inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Company`>.name: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Company`.name
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Company`>.name: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Company`.name
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Company`>.name: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Company`.name
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Company`>.name: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Company`.name
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Company`>.name: arrow.optics.Getter<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Company`.name
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Company`>.name: arrow.optics.Setter<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Company`.name
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Company`>.name: arrow.optics.Traversal<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Company`.name
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Company`>.name: arrow.optics.Fold<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Company`.name

inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Company`>.address: arrow.optics.Lens<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Company`.address
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Company`>.address: arrow.optics.Lens<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Company`.address
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Company`>.address: arrow.optics.Optional<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Company`.address
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Company`>.address: arrow.optics.Optional<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Company`.address
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Company`>.address: arrow.optics.Getter<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Company`.address
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Company`>.address: arrow.optics.Setter<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Company`.address
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Company`>.address: arrow.optics.Traversal<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Company`.address
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Company`>.address: arrow.optics.Fold<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Company`.address

==> arrow-docs-0.9.0-sources.jar: arrow/optics/Company$$optics.kt <==
package `arrow`.`optics`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `arrow`.`optics`.`Company`.Companion.iso: arrow.optics.Iso<`arrow`.`optics`.`Company`, arrow.core.Tuple2<`kotlin`.`String`, `arrow`.`optics`.`Address`>> inline get()= arrow.optics.Iso(
  get = { company: `arrow`.`optics`.`Company` -> arrow.core.Tuple2(company.`name`, company.`address`) },
  reverseGet = { tuple: arrow.core.Tuple2<`kotlin`.`String`, `arrow`.`optics`.`Address`> -> `arrow`.`optics`.`Company`(tuple.a, tuple.b) }
)

inline val `arrow`.`optics`.`Company`.Companion.name: arrow.optics.Lens<`arrow`.`optics`.`Company`, `kotlin`.`String`> inline get()= arrow.optics.Lens(
  get = { company: `arrow`.`optics`.`Company` -> company.`name` },
  set = { company: `arrow`.`optics`.`Company`, value: `kotlin`.`String` -> company.copy(`name` = value) }
)

inline val `arrow`.`optics`.`Company`.Companion.address: arrow.optics.Lens<`arrow`.`optics`.`Company`, `arrow`.`optics`.`Address`> inline get()= arrow.optics.Lens(
  get = { company: `arrow`.`optics`.`Company` -> company.`address` },
  set = { company: `arrow`.`optics`.`Company`, value: `arrow`.`optics`.`Address` -> company.copy(`address` = value) }
)




inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Company`>.name: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Company`.name
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Company`>.name: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Company`.name
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Company`>.name: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Company`.name
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Company`>.name: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Company`.name
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Company`>.name: arrow.optics.Getter<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Company`.name
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Company`>.name: arrow.optics.Setter<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Company`.name
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Company`>.name: arrow.optics.Traversal<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Company`.name
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Company`>.name: arrow.optics.Fold<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Company`.name

inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Company`>.address: arrow.optics.Lens<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Company`.address
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Company`>.address: arrow.optics.Lens<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Company`.address
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Company`>.address: arrow.optics.Optional<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Company`.address
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Company`>.address: arrow.optics.Optional<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Company`.address
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Company`>.address: arrow.optics.Getter<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Company`.address
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Company`>.address: arrow.optics.Setter<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Company`.address
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Company`>.address: arrow.optics.Traversal<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Company`.address
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Company`>.address: arrow.optics.Fold<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Company`.address
